@@ -5,14 +5,16 @@
 */
 
 #include "categoryhierarchyreader.h"
-#include "categoryconfig.h"
 
 #include <QComboBox>
 
-#include <QTreeWidget>
-
 using namespace CalendarSupport;
 
+namespace CategoryConfig
+{
+static const QLatin1String categorySeparator(":");
+}
+
 inline QString &quote(QString &string)
 {
     Q_ASSERT(CategoryConfig::categorySeparator != QLatin1String("@"));
@@ -45,7 +47,8 @@ void CategoryHierarchyReader::read(const QStringList &categories)
         QStringList _path = path(category);
 
         // we need to figure out where last item and the new one differ
-        QStringList::Iterator jt, kt;
+        QStringList::Iterator jt;
+        QStringList::Iterator kt;
         int split_level = 0;
         QStringList new_path = _path; // save it for later
         for (jt = _path.begin(), kt = last_path.begin(); jt != _path.end() && kt != last_path.end(); ++jt, ++kt) {
@@ -103,38 +106,3 @@ int CategoryHierarchyReaderQComboBox::depth() const
 {
     return mCurrentDepth;
 }
-
-#ifndef QT_NO_TREEWIDGET
-
-void CategoryHierarchyReaderQTreeWidget::clear()
-{
-    mTree->clear();
-}
-
-void CategoryHierarchyReaderQTreeWidget::goUp()
-{
-    Q_ASSERT(mItem);
-    mItem = mItem->parent();
-    --mCurrentDepth;
-}
-
-void CategoryHierarchyReaderQTreeWidget::addChild(const QString &label, const QVariant &userData)
-{
-    Q_UNUSED(userData)
-
-    if (mItem) {
-        mItem = new QTreeWidgetItem(mItem, QStringList() << label);
-    } else {
-        mItem = new QTreeWidgetItem(mTree, QStringList() << label);
-    }
-
-    mItem->setExpanded(true);
-    ++mCurrentDepth;
-}
-
-int CategoryHierarchyReaderQTreeWidget::depth() const
-{
-    return mCurrentDepth;
-}
-
-#endif
