@@ -7,10 +7,10 @@
 
 #include "incidenceattachmentmodel.h"
 
-#include <EntityTreeModel>
-#include <ItemFetchJob>
-#include <ItemFetchScope>
-#include <Monitor>
+#include <Akonadi/EntityTreeModel>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
+#include <Akonadi/Monitor>
 
 using namespace CalendarSupport;
 using namespace Akonadi;
@@ -56,7 +56,7 @@ class IncidenceAttachmentModelPrivate
         }
 
         m_monitor = new Akonadi::Monitor(q_ptr);
-        m_monitor->setObjectName(QStringLiteral("IncidenceAttachmentModelMonitor"));
+        m_monitor->setObjectName(QLatin1StringView("IncidenceAttachmentModelMonitor"));
         m_monitor->setItemMonitored(m_item);
         m_monitor->itemFetchScope().fetchFullPayload(true);
         QObject::connect(m_monitor, SIGNAL(itemChanged(Akonadi::Item, QSet<QByteArray>)), q_ptr, SLOT(resetModel()));
@@ -105,10 +105,7 @@ IncidenceAttachmentModel::IncidenceAttachmentModel(QObject *parent)
 {
 }
 
-IncidenceAttachmentModel::~IncidenceAttachmentModel()
-{
-    delete d_ptr;
-}
+IncidenceAttachmentModel::~IncidenceAttachmentModel() = default;
 
 KCalendarCore::Incidence::Ptr IncidenceAttachmentModel::incidence() const
 {
@@ -165,7 +162,7 @@ QVariant IncidenceAttachmentModel::data(const QModelIndex &index, int role) cons
 {
     Q_D(const IncidenceAttachmentModel);
     if (!d->m_incidence) {
-        return QVariant();
+        return {};
     }
 
     const KCalendarCore::Attachment attachment = d->m_incidence->attachments().at(index.row());
@@ -177,7 +174,7 @@ QVariant IncidenceAttachmentModel::data(const QModelIndex &index, int role) cons
     case MimeTypeRole:
         return attachment.mimeType();
     }
-    return QVariant();
+    return {};
 }
 
 QVariant IncidenceAttachmentModel::headerData(int section, Qt::Orientation orientation, int role) const
